This is an automated email from the ASF dual-hosted git repository.

ggregory pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/commons-crypto.git


The following commit(s) were added to refs/heads/master by this push:
     new 386af8a  Javadoc
386af8a is described below

commit 386af8a10b7a3865553097060973337b1c553090
Author: Gary Gregory <garydgreg...@gmail.com>
AuthorDate: Thu Oct 19 07:29:25 2023 -0400

    Javadoc
---
 .../java/org/apache/commons/crypto/cipher/CryptoCipherFactory.java    | 4 ++--
 .../java/org/apache/commons/crypto/random/CryptoRandomFactory.java    | 2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git 
a/src/main/java/org/apache/commons/crypto/random/CryptoRandomFactory.java 
b/src/main/java/org/apache/commons/crypto/random/CryptoRandomFactory.java
index cad051a..75141fd 100644
--- a/src/main/java/org/apache/commons/crypto/random/CryptoRandomFactory.java
+++ b/src/main/java/org/apache/commons/crypto/random/CryptoRandomFactory.java
@@ -173,7 +173,7 @@ public class CryptoRandomFactory {
      * @param props the configuration properties.
      * @return CryptoRandom  the cryptoRandom object.
      * @throws GeneralSecurityException if cannot create the {@link 
CryptoRandom} class
-     * @throws IllegalArgumentException if no classname(s) are provided
+     * @throws IllegalArgumentException if no class name(s) are provided
      */
     public static CryptoRandom getCryptoRandom(final Properties props)
             throws GeneralSecurityException {

Reply via email to
diff --git 
a/src/main/java/org/apache/commons/crypto/cipher/CryptoCipherFactory.java 
b/src/main/java/org/apache/commons/crypto/cipher/CryptoCipherFactory.java
index 5da9680..c3fbdf9 100644
--- a/src/main/java/org/apache/commons/crypto/cipher/CryptoCipherFactory.java
+++ b/src/main/java/org/apache/commons/crypto/cipher/CryptoCipherFactory.java
@@ -170,12 +170,12 @@ public class CryptoCipherFactory {
      * @param transformation  algorithm/mode/padding
      * @return CryptoCipher  the cipher  (defaults to OpenSslCipher)
      * @throws GeneralSecurityException if cipher initialize failed
      * @throws IllegalArgumentException if no classname(s) were provided
      */
     public static CryptoCipher getCryptoCipher(final String transformation, 
final Properties properties) throws GeneralSecurityException {
         final List<String> names = 
Utils.splitClassNames(getCipherClassString(properties), ",");
         if (names.isEmpty()) {
-            throw new IllegalArgumentException("No classname(s) provided");
+            throw new IllegalArgumentException("No class name(s) provided");
         }
         CryptoCipher cipher = null;
         Exception lastException = null;
@@ -170,12 +170,12 @@ public class CryptoCipherFactory {
      * @return CryptoCipher  the cipher  (defaults to OpenSslCipher)
      * @throws GeneralSecurityException if cipher initialize failed
-     * @throws IllegalArgumentException if no classname(s) were provided
+     * @throws IllegalArgumentException if no class name(s) were provided
      */
     public static CryptoCipher getCryptoCipher(final String transformation, 